==> zio-aws-route53resolver_2.13-5.17.155.1-sources.jar: zio/aws/route53resolver/model/GetFirewallRuleGroupAssociationResponse.scala <==
package zio.aws.route53resolver.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetFirewallRuleGroupAssociationResponse(
    firewallRuleGroupAssociation: Option[
      zio.aws.route53resolver.model.FirewallRuleGroupAssociation
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53resolver.model.GetFirewallRuleGroupAssociationResponse = {
    import GetFirewallRuleGroupAssociationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53resolver.model.GetFirewallRuleGroupAssociationResponse
      .builder()
      .optionallyWith(
        firewallRuleGroupAssociation.map(value => value.buildAwsValue())
      )(_.firewallRuleGroupAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.route53resolver.model.GetFirewallRuleGroupAssociationResponse.ReadOnly =
    zio.aws.route53resolver.model.GetFirewallRuleGroupAssociationResponse
      .wrap(buildAwsValue())
}
object GetFirewallRuleGroupAssociationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53resolver.model.GetFirewallRuleGroupAssociationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53resolver.model.GetFirewallRuleGroupAssociationResponse =
      zio.aws.route53resolver.model.GetFirewallRuleGroupAssociationResponse(
        firewallRuleGroupAssociation.map(value => value.asEditable)
      )
    def firewallRuleGroupAssociation: Option[
      zio.aws.route53resolver.model.FirewallRuleGroupAssociation.ReadOnly
    ]
    def getFirewallRuleGroupAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.route53resolver.model.FirewallRuleGroupAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "firewallRuleGroupAssociation",
      firewallRuleGroupAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53resolver.model.GetFirewallRuleGroupAssociationResponse
  ) extends zio.aws.route53resolver.model.GetFirewallRuleGroupAssociationResponse.ReadOnly {
    override val firewallRuleGroupAssociation: Option[
      zio.aws.route53resolver.model.FirewallRuleGroupAssociation.ReadOnly
    ] = scala
      .Option(impl.firewallRuleGroupAssociation())
      .map(value =>
        zio.aws.route53resolver.model.FirewallRuleGroupAssociation.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53resolver.model.GetFirewallRuleGroupAssociationResponse
  ): zio.aws.route53resolver.model.GetFirewallRuleGroupAssociationResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53resolver_2.13-5.20.7.3-sources.jar: zio/aws/route53resolver/model/GetFirewallRuleGroupAssociationResponse.scala <==
package zio.aws.route53resolver.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetFirewallRuleGroupAssociationResponse(
    firewallRuleGroupAssociation: Optional[
      zio.aws.route53resolver.model.FirewallRuleGroupAssociation
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53resolver.model.GetFirewallRuleGroupAssociationResponse = {
    import GetFirewallRuleGroupAssociationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53resolver.model.GetFirewallRuleGroupAssociationResponse
      .builder()
      .optionallyWith(
        firewallRuleGroupAssociation.map(value => value.buildAwsValue())
      )(_.firewallRuleGroupAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.route53resolver.model.GetFirewallRuleGroupAssociationResponse.ReadOnly =
    zio.aws.route53resolver.model.GetFirewallRuleGroupAssociationResponse
      .wrap(buildAwsValue())
}
object GetFirewallRuleGroupAssociationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53resolver.model.GetFirewallRuleGroupAssociationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53resolver.model.GetFirewallRuleGroupAssociationResponse =
      zio.aws.route53resolver.model.GetFirewallRuleGroupAssociationResponse(
        firewallRuleGroupAssociation.map(value => value.asEditable)
      )
    def firewallRuleGroupAssociation: Optional[
      zio.aws.route53resolver.model.FirewallRuleGroupAssociation.ReadOnly
    ]
    def getFirewallRuleGroupAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.route53resolver.model.FirewallRuleGroupAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "firewallRuleGroupAssociation",
      firewallRuleGroupAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53resolver.model.GetFirewallRuleGroupAssociationResponse
  ) extends zio.aws.route53resolver.model.GetFirewallRuleGroupAssociationResponse.ReadOnly {
    override val firewallRuleGroupAssociation: Optional[
      zio.aws.route53resolver.model.FirewallRuleGroupAssociation.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.firewallRuleGroupAssociation())
      .map(value =>
        zio.aws.route53resolver.model.FirewallRuleGroupAssociation.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53resolver.model.GetFirewallRuleGroupAssociationResponse
  ): zio.aws.route53resolver.model.GetFirewallRuleGroupAssociationResponse.ReadOnly =
    new Wrapper(impl)
}
